@@ -141,7 +141,7 @@ dsn_config_new (void)
 	/* create the data source list */
 	priv->dsn_list = gnome_db_grid_new ();
 
-	title = g_strdup_printf ("<span foreground=\"white\"><b>%s</b>\n%s</span>", _("Data Sources"),
+	title = g_strdup_printf ("<b>%s</b>\n%s", _("Data Sources"),
 				 _("Configured data sources in the system"));
 	gnome_db_grid_set_title (GNOME_DB_GRID (priv->dsn_list), title);
 	g_free (title);
