@@ -30,7 +30,7 @@
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-list.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <bonobo/bonobo-i18n.h>
+#include "gnome-db-i18n.h"
 
 #define PARENT_TYPE GTK_TYPE_VBOX
 
@@ -515,3 +515,49 @@ gnome_db_form_set_model (GnomeDbForm *form, GdaDataModel *model)
 	setup_widgets_for_model (form);
 	g_signal_emit (G_OBJECT (form), form_signals[MODEL_CHANGED], 0);
 }
+
+/**
+ * gnome_db_form_get_current_row
+ * @form: a #GnomeDbForm widget.
+ *
+ * Get the row currently being shown (navigator form) or currently selected
+ * (list form) by the given form widget.
+ *
+ * Returns: the current row.
+ */
+gint
+gnome_db_form_get_current_row (GnomeDbForm *form)
+{
+	g_return_val_if_fail (GNOME_DB_IS_FORM (form), -1);
+
+	switch (form->priv->type) {
+	case GNOME_DB_FORM_TYPE_NAVIGATOR :
+		return form->priv->navigator_current_row;
+	case GNOME_DB_FORM_TYPE_LIST :
+	}
+
+	return -1;
+}
+
+/**
+ * gnome_db_form_set_current_row
+ * @form: a #GnomeDbForm widget.
+ * @row: the new row to display.
+ *
+ * Sets the current row on the given form widget.
+ */
+void
+gnome_db_form_set_current_row (GnomeDbForm *form, gint row)
+{
+	g_return_if_fail (GNOME_DB_IS_FORM (form));
+	g_return_if_fail (row >= 0);
+	g_return_if_fail (row < gda_data_model_get_n_rows (form->priv->data_model));
+
+	switch (form->priv->type) {
+	case GNOME_DB_FORM_TYPE_NAVIGATOR :
+		form->priv->navigator_current_row = row;
+		show_navigator_row (form);
+		break;
+	case GNOME_DB_FORM_TYPE_LIST :
+	}
+}
