@@ -152,21 +152,15 @@ static void
 gnome_db_gray_bar_style_set (GtkWidget *w, GtkStyle *previous_style)
 {
 	static int in_style_set = 0;
-	GtkRcStyle *rc_style;
+	GtkStyle   *style;
 
 	if (in_style_set > 0)
                 return;
 
         in_style_set ++;
 
-	rc_style = gtk_rc_style_new ();
-	rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_BG;
-	rc_style->bg[GTK_STATE_NORMAL].red   = 0x8000;
-        rc_style->bg[GTK_STATE_NORMAL].green = 0x8000;
-        rc_style->bg[GTK_STATE_NORMAL].blue  = 0x8000;
-
-	gtk_widget_modify_style (w, rc_style);
-        gtk_rc_style_unref (rc_style);
+	style = gtk_rc_get_style (GTK_WIDGET (w));
+	gtk_widget_modify_bg (GTK_WIDGET (w), GTK_STATE_NORMAL, &style->bg[GTK_STATE_ACTIVE]);
 
 	in_style_set --;
 
@@ -319,20 +313,14 @@ gnome_db_gray_bar_finalize (GObject *object)
 
 	g_return_if_fail (GNOME_DB_IS_GRAY_BAR (bar));
 
-	if (bar->priv->label)
-		g_free (bar->priv->label);
-	bar->priv->label = NULL;
-	
-	if (bar->priv->icon)
-		g_free (bar->priv->icon);
-	bar->priv->icon = NULL;
+	if (bar->priv) {
+		bar->priv->label = NULL;
+		bar->priv->icon = NULL;
+		bar->priv->hbox = NULL;
 
-	if (bar->priv->hbox)
-		g_free (bar->priv->hbox);
-	bar->priv->hbox = NULL;
-
-	g_free (bar->priv);
-	bar->priv = NULL;
+		g_free (bar->priv);
+		bar->priv = NULL;
+	}
 
 	parent_class->finalize (object);
 }
