@@ -20,6 +20,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <string.h>
 #include <glib/gfileutils.h>
 #include <libgda/gda-util.h>
 #include <gtk/gtkdialog.h>
@@ -29,6 +30,7 @@
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeview.h>
 #include <gtk/gtkwindow.h>
+#include <gtk/gtkimagemenuitem.h>
 #include <gobject/gmarshal.h>
 #include <libgnomedb/gnome-db-form.h>
 #include <libgnomedb/gnome-db-gray-bar.h>
