@@ -20,16 +20,19 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
 #include <libgda/libgda.h>
 #include <libgnomedb/gnome-db-grid.h>
+#ifdef BUILD_WITH_GNOME
 #include <libgnomedb/gnome-db-window.h>
 #include <libgnomeui/gnome-ui-init.h>
+#else
+#include <gtk/gtk.h>
+#endif
 
 static void
-window_closed_cb (GnomeDbWindow *window, gpointer user_data)
+window_closed_cb (GtkWindow *window, gpointer user_data)
 {
-	gda_main_quit ();
+	gnome_db_main_quit ();
 }
 
 static GdaDataModel *
@@ -50,13 +53,13 @@ create_data_model (void)
 		values = g_list_append (values, gda_value_new_string ("Another string"));
 		values = g_list_append (values, gda_value_new_double (4560.45672113323093));
 
-		gda_data_model_array_append_row (GDA_DATA_MODEL_ARRAY (model), values);
+		gda_data_model_append_row (model, values);
 
 		g_list_foreach (values, (GFunc) gda_value_free, NULL);
 		g_list_free (values);
 	}
 
-	return GDA_DATA_MODEL (model);
+	return model;
 }
 
 static void
@@ -66,29 +69,49 @@ create_window (gpointer user_data)
 	GtkWidget *grid;
 	GdaDataModel *model;
 
+#ifdef BUILD_WITH_GNOME
 	window = gnome_db_window_new ("test-grid", NULL, NULL, NULL, NULL);
+#else
+	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
+	gtk_window_set_title (GTK_WINDOW(window), "test-grid");
+#endif
 	g_signal_connect (G_OBJECT (window), "close", G_CALLBACK (window_closed_cb), NULL);
 	gtk_widget_set_usize (window, 500, 400);
 	grid = gnome_db_grid_new ();
 	gtk_widget_show (grid);
+#ifdef BUILD_WITH_GNOME
 	gnome_db_window_set_contents (GNOME_DB_WINDOW (window), grid);
+#else
+	gtk_container_add (GTK_CONTAINER (window), grid);
+#endif
 
 	/* create the data model to be shown */
 	model = create_data_model ();
 	gnome_db_grid_set_model (GNOME_DB_GRID (grid), GDA_DATA_MODEL (model));
 	g_object_unref (G_OBJECT (model));
 	
+#ifdef BUILD_WITH_GNOME
 	gnome_db_window_show (GNOME_DB_WINDOW (window));
+#else
+	gtk_widget_show_all (window);
+#endif
 }
 
 int
 main (int argc, char *argv[])
 {
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);	
+
 	gda_init ("test-grid", VERSION, argc, argv);
+#ifdef BUILD_WITH_GNOME
 	gnome_program_init ("test-grid", VERSION,
                             LIBGNOMEUI_MODULE,
                             argc, argv, NULL);
+#else
+	gtk_init (&argc, &argv);
+#endif
 
-	gda_main_run ((GdaInitFunc) create_window, NULL);
+	gnome_db_main_run ((GdaInitFunc) create_window, NULL);
 	return 0;
 }
